@@ -14,6 +14,13 @@ use IPC::Run;
 use App::Multigit::Repo;
 use App::Multigit::Loop qw(loop);
 
+use Exporter 'import';
+
+our @EXPORT_OK = qw/
+    mgconfig mg_parent all_repositories 
+    base_branch set_base_branch mg_each
+/;
+
 =head1 NAME
 
 App::Multigit - Run commands on a bunch of git repositories without having to
@@ -25,7 +32,7 @@ Version 0.01
 
 =cut
 
-our $VERSION = '0.03';
+our $VERSION = '0.04';
 
 =head1 FUNCTIONS
 
@@ -175,6 +182,16 @@ sub each {
     ;
 }
 
+=head2 mg_each
+
+This is the exported name of C<each>
+
+    use App::Multigit qw/mg_each/;
+
+=cut
+
+*mg_each = \&each;
+
 sub _run_in_repo {
     my ($cmd, $repo, $config) = @_;
 
@@ -246,6 +263,46 @@ sub init {
     }
 }
 
+=head2 base_branch
+
+Returns the branch that the base repository is on; i.e. the repository that
+contains the C<.mgconfig> or equivalent.
+
+The purpose of this is to switch the entire project onto a feature branch;
+scripts can use this as the cue to work against a branch other than master.
+
+This will die if the base repository is not on a branch, because if you've asked
+for it, giving you a default will more likely be a hindrance than a help.
+
+=cut
+
+sub base_branch() {
+    my $dir = mg_parent;
+
+    my ($stdout) = capture {
+        system qw(git -C), $dir, qw(branch)
+    };
+
+    my ($branch) = $stdout =~ /\* (.+)/;
+    return $branch if $branch;
+
+    die "The base repository is not on a branch!";
+}
+
+=head2 set_base_branch($branch)
+
+Checks out the provided branch name on the parent repository
+
+=cut
+
+sub set_base_branch {
+    my $base_branch = shift;
+
+    my ($stdout, $stderr) = capture {
+        system qw(git -C), mg_parent, qw(checkout -B), $base_branch
+    };
+}
+
 1;
 
 __END__
