@@ -8,7 +8,7 @@ use Cwd 'getcwd';
 
 use 5.014;
 
-our $VERSION = '0.03';
+our $VERSION = '0.04';
 
 =encoding utf8
 
@@ -64,7 +64,7 @@ If it is an ARRAY ref, it is run with IO::Async::Process, with C<stdout> sent
 to the process's STDIN.
 
 A Future object is returned. When the command finishes, the Future is completed
-with a hash-shaped list identical to the one C<ruN> accepts.
+with a hash-shaped list identical to the one C<run> accepts.
 
 =head3 data
 
@@ -163,8 +163,10 @@ sub gather {
     my ($self, %data) = @_;
 
     no warnings 'uninitialized';
-    $data{stdout} .= delete $data{past_stdout};
-    $data{stderr} .= delete $data{past_stderr};
+    my $stdout = join "\n", grep { $_ } delete $data{past_stdout}, $data{stdout};
+    my $stderr = join "\n", grep { $_ } delete $data{past_stderr}, $data{stderr};
+    $data{stdout} = $stdout;
+    $data{stderr} = $stderr;
 
     Future->done(%data);
 }
@@ -176,12 +178,9 @@ Intended for currying, and accepts a hash-shaped list à la C<run>.
 Returns a Future that yields a two-element list of the directory - from the
 config - and the STDOUT from the command, indented with tabs.
 
-If %data is empty, the Future yields nothing. By this mechanism, you can avoid
-reporting about a repository entirely.
-
 Use C<gather> to collect STDOUT/STDERR from previous commands too.
 
-Intended for use as a hash constructor.
+The yielded list is intended for use as a hash constructor.
 
 
     my $future = App::Multigit::each(sub {
@@ -200,11 +199,10 @@ Intended for use as a hash constructor.
 =cut
 
 sub report {
-    my $repo = shift;
+    my $self = shift;
     my %data = @_;
-    return Future->done if not @_;
 
-    my $dir = $repo->config->{dir};
+    my $dir = $self->config->{dir};
 
     my $output = do { 
         no warnings 'uninitialized';
